@@ -1,5 +1,8 @@
 from importlib import import_module
-from s3_parse_url import DataSource
+from typing import Union
+
+from s3_parse_url import parse_s3_url
+from s3_parse_url.base import S3DataSource
 
 
 def import_module_if_installed(package_name: str):
@@ -9,11 +12,16 @@ def import_module_if_installed(package_name: str):
         return None
 
 
+Parseable = Union[str, S3DataSource]
 aiobotocore = import_module_if_installed("aiobotocore")
 boto3 = import_module_if_installed("boto3")
 
 
-def get_boto_client_kwargs(datasource: DataSource, **kwargs):
+def get_boto_client_kwargs(url: Parseable, **kwargs):
+    if isinstance(url, S3DataSource):
+        datasource = url
+    else:
+        datasource = parse_s3_url(url)
     return {
         "aws_access_key_id": datasource.access_key_id,
         "aws_secret_access_key": datasource.secret_access_key,
@@ -22,15 +30,18 @@ def get_boto_client_kwargs(datasource: DataSource, **kwargs):
     }
 
 
-def get_aiobotocore_client(datasource: DataSource, **kwargs):
+def get_aiobotocore_client(url: str, **kwargs):
     if aiobotocore is None:
         raise ValueError("aiobotocore not installed")
-    return aiobotocore.get_session().create_client(
-        "s3", **get_boto_client_kwargs(datasource, **kwargs),
+
+    from aiobotocore.session import get_session
+
+    return get_session().create_client(
+        "s3", **get_boto_client_kwargs(url, **kwargs),
     )
 
 
-def get_boto3_client(datasource: DataSource, **kwargs):
+def get_boto3_client(url: str, **kwargs):
     if boto3 is None:
         raise ValueError("boto3 not installed")
-    return boto3.client("s3", **get_boto_client_kwargs(datasource, **kwargs))
+    return boto3.client("s3", **get_boto_client_kwargs(url, **kwargs))
